package com.ozs.service.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.utils.StringUtils;
import com.ozs.common.utils.bean.BeanUtils;
import com.ozs.service.entity.BaseCameraVersion;
import com.ozs.service.entity.vo.BaseCameraVersionVo;
import com.ozs.service.mapper.BaseCameraVersionMapper;
import com.ozs.service.service.BaseCameraVersionService;
import com.ozs.system.service.ISysDictDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @Author : sunhh
 * @create 2023/4/24 11:22
 */
@Service
public class BaseCameraVersionServiceImpl extends ServiceImpl<BaseCameraVersionMapper, BaseCameraVersion> implements BaseCameraVersionService {

    @Autowired
    private BaseCameraVersionMapper baseCameraVersionMapper;
    @Autowired
    private ISysDictDataService dictDataService;

    @Override
    public AjaxResult cameraVersionAdd(BaseCameraVersion baseCameraVersion, String userId) {
        LambdaQueryWrapper<BaseCameraVersion> wrapper = new LambdaQueryWrapper<>();
        if (!StringUtils.isEmptySunhh(baseCameraVersion) && !StringUtils.isEmptySunhh(baseCameraVersion.getVersionNum())) {
            wrapper.eq(BaseCameraVersion::getVersionNum, baseCameraVersion.getVersionNum());
        }
        if (!StringUtils.isEmptySunhh(baseCameraVersion) && !StringUtils.isEmptySunhh(baseCameraVersion.getVersionName())) {
            wrapper.eq(BaseCameraVersion::getVersionName, baseCameraVersion.getVersionName());
        }
        BaseCameraVersion baseCameraVersion1 = baseCameraVersionMapper.selectOne(wrapper);
        if (StringUtils.isEmptySunhh(baseCameraVersion1)) {
            baseCameraVersion.setCreateBy(userId);
            baseCameraVersion.setUpdateBy(userId);
            Date date = new Date();
            baseCameraVersion.setCreateTime(date);
            baseCameraVersion.setUpdateTime(date);
            baseCameraVersionMapper.insert(baseCameraVersion);
        } else {
            return AjaxResult.error("当前版本号或版本名称已存在，请核对后在添加！");
        }
        return AjaxResult.success();
    }

    @Override
    public IPage<BaseCameraVersionVo> cameraVersionList(BaseCameraVersionVo baseCameraVersionVo) {
        LambdaQueryWrapper<BaseCameraVersion> wrapper = new LambdaQueryWrapper<>();
        if (!StringUtils.isEmptySunhh(baseCameraVersionVo) && !StringUtils.isEmptySunhh(baseCameraVersionVo.getVersionNum())) {
            wrapper.eq(BaseCameraVersion::getVersionNum, baseCameraVersionVo.getVersionNum());
        }
        if (!StringUtils.isEmptySunhh(baseCameraVersionVo) && !StringUtils.isEmptySunhh(baseCameraVersionVo.getVersionName())) {
            wrapper.eq(BaseCameraVersion::getVersionName, baseCameraVersionVo.getVersionName());
        }
        if (!StringUtils.isEmptySunhh(baseCameraVersionVo) && !StringUtils.isEmptySunhh(baseCameraVersionVo.getUpgradeType())) {
            wrapper.eq(BaseCameraVersion::getUpgradeType, baseCameraVersionVo.getUpgradeType());
        }
        int pageNum = Integer.parseInt(baseCameraVersionVo.getPageNum().toString());
        int pageSize = Integer.parseInt(baseCameraVersionVo.getPageSize().toString());
        com.github.pagehelper.Page<BaseCameraVersion> page = PageHelper.startPage(pageNum, pageSize)
                .doSelectPage(() -> baseCameraVersionMapper.selectList(wrapper));
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<BaseCameraVersionVo> pageR =
                new com.baomidou.mybatisplus.extension.plugins.pagination.Page<>(pageNum, pageSize);
        if (!ObjectUtils.isEmpty(page) && page.getResult().size() > 0) {
            List<BaseCameraVersionVo> dto1 = page.getResult().stream().map(o -> {
                BaseCameraVersionVo baseCameraVersionVo1 = new BaseCameraVersionVo();
                BeanUtils.copyProperties(o, baseCameraVersionVo1);
                // 升级类型 1:算法升级,2:硬件升级,3:算法及硬件升级
                String upgradeTypeName = dictDataService.selectDictLabel("upgrade_type", o.getUpgradeType());
                if (!StringUtils.isEmptySunhh(upgradeTypeName)) {
                    baseCameraVersionVo1.setUpgradeTypename(upgradeTypeName);
                }
                return baseCameraVersionVo1;
            }).collect(Collectors.toList());
            pageR.setRecords(dto1);
        }
        return pageR;
    }
}
